@@ -255,13 +255,13 @@ static GigoloBookmark *get_bookmark_from_uri(GigoloWindow *window, const gchar *
 	for (i = 0; i < bml->len && ! found; i++)
 	{
 		bm = g_ptr_array_index(bml, i);
-		tmp_uri = gigolo_bookmark_get_uri(bm);
+		tmp_uri = gigolo_bookmark_get_uri_escaped(bm);
 		if (gigolo_str_equal(uri, tmp_uri))
 			found = TRUE;
 
 		g_free(tmp_uri);
 	}
-	return bm;
+	return (found) ? bm : NULL;
 }
 
 
@@ -276,7 +276,7 @@ static void mount_from_bookmark(GigoloWindow *window, GigoloBookmark *bookmark,
 
 	priv = GIGOLO_WINDOW_GET_PRIVATE(window);
 
-	uri = gigolo_bookmark_get_uri(bookmark);
+	uri = gigolo_bookmark_get_uri_escaped(bookmark);
 
 	if (show_dialog)
 	{
@@ -423,8 +423,8 @@ static void action_about_cb(G_GNUC_UNUSED GtkAction *action, GigoloWindow *windo
 	gtk_show_about_dialog(GTK_WINDOW(window),
 		"authors", authors,
 		"logo-icon-name", gigolo_get_application_icon_name(),
-		"comments", "A simple frontend to easily connect to remote filesystems",
-		"copyright", "Copyright 2008-2009 Enrico Tröger",
+		"comments", _("A simple frontend to easily connect to remote filesystems"),
+		"copyright", _("Copyright 2008-2009 Enrico Tröger"),
 		"website", "http://www.uvena.de/gigolo/",
 		"version", VERSION,
 		"translator-credits", _("translator-credits"),
